Ritual.Room = function (game) {};

Ritual.Room.prototype = {
    
    create: function () {

        // TileMap:Tiles:JSON
        this.map = game.add.tilemap('map');
        this.map.addTilesetImage('backgroundTile', 'imgBackground', 20, 20);
        this.map.addTilesetImage('shadowTile', 'imgShadow', 20, 20);
        this.background = this.map.createLayer('backgroundLayer');
        this.collision = this.map.createLayer('blockedLayer');
        this.map.setCollisionBetween(1, 2700, true, 'blockedLayer');
        this.background.resizeWorld();
        
        // Sprite:Plate
        this.createPlate();
        
        // Sprite:Movable
        this.createMovable();
        
        // Sprite:Static
        this.createStatic();
        
        // ꝉ Under Shadow ... ↆ NOT Under Shadow 
        this.shadow = this.map.createLayer('shadowLayer');
        this.shadow.alpha = 0;
        
        // Sprite:Player
        var result = this.findObjectsByType('start', this.map, 'objectsLayer');
        this.player = game.add.sprite(result[0].x, result[0].y, 'imgPlayerHB');
        
        game.physics.arcade.enable(this.player);
        game.camera.follow(this.player);
        this.player.body.collideWorldBounds = true;
        this.player.alpha = 0;
        
        // Sprite:Player:Skin
        this.playerSkin = game.add.sprite(result[0].x, result[0].y, 'player');
        
        this.playerSkin.animations.add('static', [0]);
        this.playerSkin.animations.add('down', [0,1,2,3,16,17,18,19]);
        this.playerSkin.animations.add('up', [5,6,7,8,21,22]);
        this.playerSkin.animations.add('side', [10,11,12,13,14,26,27,28,29,30]);
        
        this.animationCurrent = 'static';
        this.playerSkin.animations.play(this.animationCurrent, 1, false);
        this.positionSkin(this.player, this.playerSkin);
        this.playerSkin.alpha = 1;
        
        // Sprite:Player:Skin:Light
        this.playerSkinLight = game.add.sprite(result[0].x, result[0].y, 'player-light');
        
        this.playerSkinLight.animations.add('static', [0]);
        this.playerSkinLight.animations.add('down', [0,1,2,3,16,17,18,19]);
        this.playerSkinLight.animations.add('up', [5,6,7,8,21,22]);
        this.playerSkinLight.animations.add('side', [10,11,12,13,14,26,27,28,29,30]);
        
        this.animationCurrent = 'static';
        this.playerSkinLight.animations.play(this.animationCurrent, 1, false);
        this.positionSkin(this.player, this.playerSkinLight);
        this.playerSkinLight.alpha = 0;
        
        // Sprite:Actionable
        this.createActionable();
        
        // SpriteBoss
        var result = this.findObjectsByType('startBoss', this.map, 'objectsLayer')
        this.boss = game.add.sprite(result[0].x, result[0].y, 'boss');
        
        game.physics.arcade.enable(this.boss);
        this.boss.body.collideWorldBounds = true;
        this.boss.body.bounce.set(1);
        
        this.boss.animations.add('static', [0]);
        this.boss.animations.add('down', [0,1,2,3,12,13]);
        this.boss.animations.add('up', [8,9,10,11,20,21]);
        this.boss.animations.add('side', [4,5,6,7,16,17]);
        
        this.boss.animations.play('static', 0, false);
        
        // Variables
        this.buffer = 0;
        this.bufferTambourin = 0;
        this.lightOn = 0;
        this.playerSkinAlpha = 0;
        this.playerSkinLightAlpha = 0;
        this.scenarioMessage = 0;
        this.scenarioMessageUp = false;
        this.currentLight = 1;
        this.bossSequence = 0;
        this.bossHurt = 0;
        this.windowFinal = 0;
        
        /* Sons (SFX) */
		this.tambourSound = this.add.audio('tambour');
		this.rireSound = this.add.audio('rire');
		this.briquetSound = this.add.audio('briquet');
		this.mirorSound = this.add.audio('miror-break');
		this.errorSound = this.add.audio('error');
		this.levelMusic = this.add.audio('level-music');
        this.doorSound = this.add.audio('door');
        this.mortSound = this.add.audio('sound');
        
        this.levelMusic.volume = 0.05;
        this.levelMusic.play();
        
        // GamePad
        game.input.gamepad.start();
        this.pad = game.input.gamepad.pad1;
        
    },
    
    update: function () {
        
       // if(this.levelMusic.isPlaying == false && this.endState != true){this.levelMusic.play();}
        
        // Flag
        this.flagCollidePlayerCollisionEvent = false;
        
        // Colision
        game.physics.arcade.collide(this.player, this.collision);
        game.physics.arcade.collide(this.player, this.statics, this.touchStatic, null, this);
        game.physics.arcade.collide(this.player, this.movable, this.touchMovable, null, this);
        game.physics.arcade.overlap(this.player, this.actionable, this.touchActionable, null, this);
        game.physics.arcade.overlap(this.movable, this.plates, this.touchPlateByMovable, null, this);
        game.physics.arcade.overlap(this.player, this.plates, this.touchPlateByPlayer, null, this);
        game.physics.arcade.overlap(this.player, this.boss, this.bossLogicTouch, null, this);
 
        // Moving the player sprite
        this.movePlayer();
        
        // Define the animation for the player sprite
        this.defineAnimation();
        
        // Boss
        this.bossLogic();
        this.bossHurt = 0;
        
        // Reset Movable Velocity
        if(this.flagCollidePlayerCollisionEvent == false) {
            this.movable.forEach(function(item) {
                item.body.velocity.x = 0;
                item.body.velocity.y = 0;
            }, this);
        }
        
        // Lighter:On:Off
        if(this.buffer != 0)
        {
           this.buffer++;
        }
        
        if (this.buffer >= 20) {
           this.buffer = 0;
        }
        
        if (this.pad.justPressed(Phaser.Gamepad.XBOX360_Y) && this.buffer == 0 && this.lighterLoot) {
            var tmp;
            tmp = this.playerSkin.alpha;
            this.playerSkin.alpha = this.playerSkinLight.alpha;
            this.playerSkinLight.alpha = tmp;
            this.buffer = 1;
            if (this.playerSkinLight.alpha == 1) {
                this.briquetSound.volume = 0.5;
                this.briquetSound.play();
            }
        }
        
        if (this.pad.justPressed(Phaser.Gamepad.XBOX360_A) && this.buffer == 0) {
            // Dialog:Triger
            this.deleteMessage();
            if (this.scenarioMessageUp) {
                this.scenarioMessage++;
                this.scenarioMessageUp = false;
            }
            this.buffer = 1;
        }
        
        // Wall:Trigger
        if (this.lightOn == 6) {
            this.wallSprite.kill();
            this.lightOn = 7;
        }
        
        if(this.bufferTambourin != 0)
        {
           this.bufferTambourin++;
        }
        
        if (this.bufferTambourin >= 55) {
           this.bufferTambourin = 0;
           if(this.scenarioMessageUp != true){this.tambourinOff = false};
        }
        
        if (typeof this.playerTambourin !== 'undefined') {
            this.positionSkin(this.player, this.playerTambourin);
        }
        
        // # MESSAGES # //
                
        /*/ Tambourin Triger 
        if (this.tambourinOff && this.message_2 != true) {
            this.message('tam-tam', 'Hey viendez faire la fête ici XXDD !!!', 470, 650);
            this.message_2 = true;
        }//*/
        
        if (this.dagueLoot && this.message_3 != true) {
            this.message('bob', 'Une dague ... c\'est quoi cette embrouille ?!?', 50, 350);
            this.message_3 = true;
        }
        
        if (this.lighterLoot && this.message_4 != true) {
            this.message('bob', 'A voilà mon briquet, si je passe à coté des bougies'+'\n'+'lorsqu\'il est allumé je pourrais les enflammées ...', 370, 680);
            this.message_4 = true;
        }
        
        if (this.scenarioMessage == 0 && this.scenarioMessageUp == false) {
            this.message('bob', 'Je suis un peu triste aujourd\'hui, mmh ...', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 1 && this.scenarioMessageUp == false) {
            this.message('bob', 'Et si ...', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 2 && this.scenarioMessageUp == false) {
            this.message('bob', 'Et si je jouais un peu de tambourin ... ?!', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 3 && this.scenarioMessageUp == false && this.tambourin_1) {
            this.rireSound.volume = 0.05;
			this.rireSound.play();
            this.message('@@_TAMBOURIN_@@', 'Je suis enfermé là dedans depuis trop longtemps deja !', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 4 && this.scenarioMessageUp == false) {
            this.message('@@_TAMBOURIN_@@', 'TU DOIS ME SORTIR DE LA !', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 5 && this.scenarioMessageUp == false) {
            this.message('bob', 'Qui ? Qui me parle, Quoi ?!', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 6 && this.scenarioMessageUp == false) {
            this.message('@@_TAMBOURIN_@@', 'Ca viens du tambourin papy moujo', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 7 && this.scenarioMessageUp == false) {
            this.message('bob', 'Quoi ? ... mais comment ?', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 8 && this.scenarioMessageUp == false) {
            this.message('@@_TAMBOURIN_@@', 'Je suis une belle princesse un méchant sorcier'+'\n'+' ma enfermer ici !', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 9 && this.scenarioMessageUp == false) {
            this.message('@@_TAMBOURIN_@@', 'AIDE MOI !', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 10 && this.scenarioMessageUp == false) {
            this.message('bob', 'Une princesse ! ... et je dois faire quoi au juste ??', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 11 && this.scenarioMessageUp == false) {
            this.message('@@_TAMBOURIN_@@', 'Commence par rétablir "l\'armonie" de la pièce', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 12 && this.scenarioMessageUp == false) {
            this.message('@@_TAMBOURIN_@@', 'Reviens jouer du tambourin l\'orsque du aura fini', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 13 && this.scenarioMessageUp == false) {
            this.firstTambourinClimax = true;
            this.message('bob', 'Heu ... ok ...', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 14 && this.bufferTambourin == 0) {
            this.tambourinOff = false;
        }
        
        if (this.scenarioMessage == 14 && this.scenarioMessageUp == false && this.tambourin_2) {
            this.rireSound.volume = 0.05;
			this.rireSound.play();
            this.shadow.alpha = 0.1;
            this.message('@@_TAMBOURIN_@@', 'On est sur la bonne voie ...', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 15 && this.scenarioMessageUp == false) {
            this.message('@@_TAMBOURIN_@@', 'Mais cette espace est surement trop lumineux !', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 16 && this.scenarioMessageUp == false) {
            this.message('@@_TAMBOURIN_@@', 'Trouve un moyen d\'y remedier', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 17 && this.scenarioMessageUp == false) {
            this.windowAction = true;
            this.message('@@_TAMBOURIN_@@', 'N\'hésites pas à rejouer du tambour pour vérifier les ondes', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 18 && this.bufferTambourin == 0) {
            this.tambourinOff = false;
        }
        
        if (this.scenarioMessage == 18 && this.scenarioMessageUp == false && this.tambourin_3) {
            this.rireSound.volume = 0.05;
			this.rireSound.play();
            this.shadow.alpha = 0.5;
            this.ligtherAction = true;
            this.message('@@_TAMBOURIN_@@', 'OUI ! ... de mieux en mieux, '+'\n'+'mais j\'y pense tu n\'y vois presque rien', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 19 && this.scenarioMessageUp == false) {
            this.message('@@_TAMBOURIN_@@', 'Il y a surement moyen d\'allumer une lumière !', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 20 && this.bufferTambourin == 0) {
            this.tambourinOff = false;
        }
        
        if (this.scenarioMessage == 20 && this.scenarioMessageUp == false && this.tambourin_4) {
            this.rireSound.volume = 0.05;
			this.rireSound.play();
            this.shadow.alpha = 0.6;
            this.doorSprite.animations.play('show', 0, false);
            this.spriteRightLigth.kill();
            this.spriteLeftLigth.kill();
            this.meubleSprite.kill();
            this.doorOpen = true;
            this.message('@@_TAMBOURIN_@@', 'Continue comme ça ! J\'aperçois la sortie !', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 21 && this.scenarioMessageUp == false && this.tambourin_5) {
            this.rireSound.volume = 0.1;
			this.rireSound.play();
            this.shadow.alpha = 0.7;
            this.wallSprite.kill();
            this.message('@@_TAMBOURIN_@@', 'OUI PRENDS LA RELIQUE MAINTENANT !!!', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 22 && this.bufferTambourin == 0) {
            this.tambourinOff = false;
        }
        
        if (this.scenarioMessage == 22 && this.scenarioMessageUp == false && this.tambourin_6) {
            this.rireSound.volume = 0.15;
			this.rireSound.play();
            this.shadow.alpha = 0.8;
            this.mirrorAction = true;
            this.message('@@_TAMBOURIN_@@', 'IL EST TEMPS !!! BRISE MON SORTILEGE, BRISE LE !!', 500, 620);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 23 && this.scenarioMessageUp == false && this.mirorBreak) {
            this.rireSound.volume = 0.2;
			this.rireSound.play();
            this.message('@@_TAMBOURIN_@@', '!! HAHAHAH !!', 500, 520);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 24 && this.scenarioMessageUp == false) {
            this.bossSequence = 2;
            this.message('@@_TAMBOURIN_@@', '!! MERCI D\'AVOIR BRISE LE SCEAN QUI ME RETENAIT !!', 500, 520);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 25 && this.scenarioMessageUp == false) {
            this.bossSequence = 4;
            this.windowFinal = 1;
            this.message('@@_TAMBOURIN_@@', '!! MAINTENANT TON CORPS ET HA MOI !!', 500, 520);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 26 && this.scenarioMessageUp == false && this.windowFinalOpen) {
            this.bossSequence = 6;
            this.message('@@_TAMBOURIN_@@', '!! NON JE MEURS !!', 500, 520);
            this.scenarioMessageUp = true;
        }
        
        if (this.scenarioMessage == 27 && this.scenarioMessageUp == false && this.windowFinalOpen) {
            this.endState = true;
            this.levelMusic.stop();
            this.state.start('Credit');
        }
        
    },
    
    bossLogic: function () {
        
        if (this.bossSequence == 0) {
            this.boss.alpha = 0;
            this.bossSequence++;
        }
        
        if (this.bossSequence == 2) {
            this.boss.alpha = 1;
            this.bossSequence++;
        }
        
        if (this.bossSequence == 4) {
            this.boss.body.velocity.setTo(180,180);
            this.boss.body.collideWorldBounds = true;
            this.boss.body.bounce.set(1);
            this.bossSequence++;
        }
        
        if (this.bossSequence == 6) {
            this.boss.body.velocity.setTo(0,0);
            this.boss.body.collideWorldBounds = true;
            this.boss.body.bounce.set(1);
            this.bossSequence++;
        }
        
        if (this.bossHurt == 1) {
            this.mortSound.volume = 0.05;
            this.mortSound.play();
            this.state.start('Room');
        }
        
    },
    
    bossLogicTouch: function () {
        
        if (this.bossSequence == 5) {
            this.bossHurt = 1;
        }
        
    },
    
    message: function (orateur, message, x, y) {
        
        // Rectancle
        this.dialogBox = {};
        var width = 600
        var height = 200
        var bmd = game.add.bitmapData(width, height);
 
        bmd.ctx.beginPath();
        bmd.ctx.rect(0, 0, width, height);
        bmd.ctx.fillStyle = '#000000';
        bmd.ctx.fill();
        
        this.dialogBox = game.add.sprite(x, y, bmd);
        this.dialogBox.alpha = 0.4
        
        // Title:Text
        this.titleText = this.add.text(x+20, y+20, orateur + ':', {
            font : 'Verdana',
            fontSize : '18px',
            fill : '#5A9FE8'
        });
        
        // Message:Text
        this.messageText = this.add.text(x+20, y+60, message, {
            font : 'Verdana',
            fontSize : '18px',
            fill : '#ffffff'
        });
        
        // Fix:Player
        this.playerMove = false;
        
        // Dialog:Event
        this.dialogEvent = true;
        
    },
    
    deleteMessage: function () {
        if (this.dialogEvent == true) {
            this.dialogBox.kill();
            this.titleText.kill();
            this.messageText.kill();this.tambourin_4
            this.dialogEvent = false;
            this.playerMove = true;
        }
    },
    
    positionSkin: function (sprite, skin) {
        skin.x = sprite.x + (sprite.width/2) - (skin.width/2);
        skin.y = sprite.y + (sprite.height/2) - (skin.height/2);
        skin.z = sprite.z;
    },
    
    touchPlateByPlayer: function (player, plate) {
        if(plate['uid'] == 'lighter_plate' && this.playerSkinLight.alpha == 1) {

            this.spriteRightLigth.animations.play('on', 5, true);
            this.spriteLeftLigth.animations.play('on', 5, true);
            this.spriteRightLigth.lightOn = true;
            this.spriteLeftLigth.lightOn = true;
        }
    },
    
    touchPlateByMovable: function (movable, plate) {
        if(movable['uid'] == 'pouf_depart' && plate['uid'] == 'harmony_plate') {
            this.poufOnPlate = true;
        }
    },
    
    touchStatic: function (player, statics) {
        
        if (this.pad.justPressed(Phaser.Gamepad.XBOX360_A) && statics.sprite == 'door' && this.doorBreak != true && this.doorOpen)
        {
            statics.kill();
            this.doorBreak = true;
            this.doorSound.volume = 0.2;
            this.doorSound.play();
        }
        
    },
    
    touchActionable: function (player, actionable) {
        
        if (this.playerSkinLight.alpha == 1 && actionable.sprite == 'light')
        {
            console.log(actionable['uid']);
            console.log(this.currentLight);
            console.log(actionable.animations.currentAnim.name);
            
            if (actionable['uid'] == 'light' + this.currentLight) {
                this.currentLight++;
                actionable.animations.play('on', 5, true);
            } else {
                if (actionable.animations.currentAnim.name == 'off') {
                    this.errorSound.volume = 0.5;
                    if(this.errorSound.isPlaying == false){this.errorSound.play();}
                    this.light1.animations.play('off', 0, false);                
                    this.light2.animations.play('off', 0, false);                
                    this.light3.animations.play('off', 0, false);                
                    this.light4.animations.play('off', 0, false);                
                    this.light5.animations.play('off', 0, false);                
                    this.light5.animations.play('off', 0, false);
                    this.currentLight = 1;
                }
          }
          

       }
        
        if (this.pad.justPressed(Phaser.Gamepad.XBOX360_A) && actionable.sprite == 'miror' && this.mirorBreak != true && this.mirrorAction)
        {
            actionable.animations.play('breaking', 5, false);
            this.mirorSound.volume = 0.01;
            this.mirorSound.play();
            this.mirorBreak = true;
        }
        
        if (this.pad.justPressed(Phaser.Gamepad.XBOX360_A) && actionable.sprite == 'window' && this.windowsClose != true && this.windowAction)
        {
            actionable.alpha = 1;
            actionable.animations.play('moving', 8, false);
            this.shadow.alpha = 0.3;
            this.windowsClose = true;
        }
        
        if (this.pad.justPressed(Phaser.Gamepad.XBOX360_A) && actionable.sprite == 'window' && this.windowFinal == 1)
        {
            actionable.kill();
            this.shadow.alpha = 1;
            this.windowFinalOpen = true;
        }
        
        if (this.pad.justPressed(Phaser.Gamepad.XBOX360_A) && actionable.sprite == 'tambourin' && this.tambourinOff != true)
        {
            this.tambourSound.volume = 0.8;
			this.tambourSound.play();
            
            this.tambourinSprite.animations.play('playing', 5, false);
            
            this.tambourinOff = true;
            this.bufferTambourin = 1;
            
            /**/
            
            this.tambourin_1 = true;
            if(this.firstTambourinClimax && this.poufOnPlate){this.tambourin_2 = true;}
            if(this.windowsClose){this.tambourin_3 = true;}
            if(this.spriteRightLigth.lightOn){this.tambourin_4 = true;}
            if (this.currentLight > 6) {this.tambourin_5 = true;}
            if (this.dagueLoot) {this.tambourin_6 = true;}
            /**/
            
        }
        
        if (this.pad.justPressed(Phaser.Gamepad.XBOX360_A) && actionable.sprite == 'imgDague' && this.dagueLoot != true)
        {
            this.dagueLoot = true;
            actionable.kill();
        }
        
        if (this.pad.justPressed(Phaser.Gamepad.XBOX360_A) && actionable.sprite == 'imgBallon' && this.lighterLoot != true && this.ligtherAction)
        {
            this.lighterLoot = true;
            actionable.kill();
            this.lighterSprite.kill();
        }
        
    },
    
    touchMovable: function (player, movable) {
        
        this.flagCollidePlayerCollisionEvent = true;
        
        if (this.pad.isDown(Phaser.Gamepad.XBOX360_A))
        {
            
            // Define min, max for x, y
            var minX = movable.x
            var maxX = movable.x + movable.width
            var minY = movable.y
            var maxY = movable.y + movable.height
            
            // Define movable velocity
            var movableVelocity = 40;
            
            // Define player position
            if ((this.player.x < movable.x) && (this.player.y > minY && this.player.y < maxY)) {
                if (this.animationX == 'side') {
                    movable.body.velocity.x = movableVelocity;
                }
            }
            else if ((this.player.y < movable.y) && (this.player.x > minX && this.player.x < maxX)) {
                if (this.animationY == 'down') {
                    movable.body.velocity.y = movableVelocity;
                }
            }
            else if ((this.player.y > movable.y) && (this.player.x > minX && this.player.x < maxX)) {
                if (this.animationY == 'up') {
                    movable.body.velocity.y = movableVelocity * (-1);
                }
            }
            else if ((this.player.x > movable.x) && (this.player.y > minY && this.player.y < maxY)) {
                if (this.animationX == 'side') {
                    movable.body.velocity.x = movableVelocity * (-1);
                }
            }

            // Output
            var output = '';
            
            output += 'player:' + '\n';
            output += '    x: ' + this.player.x + '\n';
            output += '    y: ' + this.player.y + '\n';
            output += '    width: ' + this.player.width + '\n';
            output += '    height: ' + this.player.height + '\n';
            output += 'movable:' + '\n';
            output += '    x: ' + movable.x + '\n';
            output += '    y: ' + movable.y + '\n';
            output += '    width: ' + movable.width + '\n';
            output += '    height: ' + movable.height;
            output += 'define:' + '\n';
            output += '    minX: ' + minX + '\n';
            output += '    maxX: ' + maxX + '\n';
            output += '    minY: ' + minY + '\n';
            output += '    maxY: ' + maxY + '\n';
            
            // console.log(output);
            
        }
        
    },
    
    movePlayer: function() {
        
        var maxVelocity = 100;
        var minVelocity = -100;
        var updatePosition = false;
        
        this.animationX = 'none';
        this.animationY = 'none';
        
        if (this.playerMove == false) {
            return false;
        }
        
        if (this.pad.isDown(Phaser.Gamepad.XBOX360_DPAD_LEFT) || this.pad.axis(Phaser.Gamepad.XBOX360_STICK_LEFT_X) < -0.1)
        {
            this.player.body.velocity.x = minVelocity;
            this.animationX = 'side';
            updatePosition = true;
            this.playerSkin.scale.x = -1;
            this.playerSkinLight.scale.x = -1;
        }
        else if (this.pad.isDown(Phaser.Gamepad.XBOX360_DPAD_RIGHT) || this.pad.axis(Phaser.Gamepad.XBOX360_STICK_LEFT_X) > 0.1)
        {
            this.player.body.velocity.x = maxVelocity;
            this.animationX = 'side';
            updatePosition = true;
            this.playerSkin.scale.x = 1;
            this.playerSkinLight.scale.x = 1;
        }
        
        if (this.pad.isDown(Phaser.Gamepad.XBOX360_DPAD_UP) || this.pad.axis(Phaser.Gamepad.XBOX360_STICK_LEFT_Y) < -0.1)
        {
            this.player.body.velocity.y = minVelocity;
            this.animationY = 'up';
            updatePosition = true;
        }
        else if (this.pad.isDown(Phaser.Gamepad.XBOX360_DPAD_DOWN) || this.pad.axis(Phaser.Gamepad.XBOX360_STICK_LEFT_Y) > 0.1)
        {
            this.player.body.velocity.y = maxVelocity;
            this.animationY = 'down';
            updatePosition = true;
        }
        
        if (this.animationX == 'none') {
            this.player.body.velocity.x = 0;
        }
        
        if (this.animationY == 'none') {
            this.player.body.velocity.y = 0;
        }
        
        if (updatePosition) {this.positionSkin(this.player, this.playerSkin);
            this.positionSkin(this.player, this.playerSkinLight);
            this.positionSkin(this.player, this.playerSkin);
            this.positionSkin(this.player, this.playerSkinLight);
        }
        
    },
    
    defineAnimation: function () {
        
        if (this.animationX == 'none' && this.animationY == 'none') {
            this.animationCurrent = 'static';
        }
        else if (this.animationX != 'none' && this.animationY == 'none') {
            this.animationCurrent = this.animationX;
        }
        else if (this.animationX == 'none' && this.animationY != 'none') {
            this.animationCurrent = this.animationY;
        }
        
        if (this.animationLast != this.animationCurrent) {
            this.playerSkin.animations.play(this.animationCurrent, 7, true);
            this.playerSkinLight.animations.play(this.animationCurrent, 7, true);
            this.animationLast = this.animationCurrent;
        }
        
    },
    
    findObjectsByType: function(type, map, layer) {
        var result = new Array();
        map.objects[layer].forEach(function(element){
            if(element.properties.type === type) {
                element.y -= map.tileHeight;
                result.push(element);
            }      
        });
        return result;
    },
    
    createMovable: function() {
        
        this.movable = game.add.group();
        this.movable.enableBody = true;
        
        result = this.findObjectsByType('movable', this.map, 'objectsLayer');
        result.forEach(function(element){
            this.createFromTiledObject(element, this.movable);
        }, this);
        
    },
    
    createStatic: function() {
        
        this.statics = game.add.group();
        this.statics.enableBody = true;
        
        result = this.findObjectsByType('static', this.map, 'objectsLayer');
        result.forEach(function(element){
            var sprite = this.createFromTiledObject(element, this.statics);
            
            if (sprite.sprite == 'imgWall') {
                this.wallSprite = sprite;
            }
            else if (sprite.sprite == 'door') {
                sprite.animations.add('normal', [0]);
                sprite.animations.add('show', [1]);
                sprite.animations.play('normal', 0, false);
                
                this.doorSprite = sprite;
            }
            else if (sprite.sprite == 'imgLighter') {
                this.lighterSprite = sprite;
            }
            else if (sprite.sprite == 'imgMeuble') {
                this.meubleSprite = sprite;
            }
            
        }, this);
        
    },
    
    createPlate: function() {
        
        this.plates = game.add.group();
        this.plates.enableBody = true;
        
        result = this.findObjectsByType('plate', this.map, 'objectsLayer');
        result.forEach(function(element){
            var sprite = this.createFromTiledObject(element, this.plates);
            sprite.alpha = 0;
        }, this);
        
    },
    
    createFromTiledObject: function(element, group) {
        
        //var blockShape = me.game.add.bitmapData(me.game.world.width, 200);
        var sprite = group.create(element.x, element.y, element.properties.sprite);
        sprite.body.immovable = true;
        sprite.sprite = element.properties.sprite;
        
        game.physics.arcade.enable([sprite], false);
        
        Object.keys(element.properties).forEach(function(key){
            sprite[key] = element.properties[key];
        });
        
        return sprite;
        
    },
    
    createActionable: function() {
        
        this.actionable = game.add.group();
        this.actionable.enableBody = true;
        
        result = this.findObjectsByType('actionable', this.map, 'objectsLayer');
        result.forEach(function(element){
            
            var sprite = this.createFromTiledObject(element, this.actionable);
            
            if (sprite.sprite == 'light') {
                sprite.animations.add('off', [0]);
                sprite.animations.add('on', [1,2,3]);
                sprite.animations.play('off', 0, false);
                if (sprite['uid'] == 'left_light') {
                    this.spriteLeftLigth = sprite;
                }
                if (sprite['uid'] == 'right_light') {
                    this.spriteRightLigth = sprite;
                }
                if (sprite['uid'] == 'light1') {this.light1 = sprite;}
                if (sprite['uid'] == 'light2') {this.light2 = sprite;}
                if (sprite['uid'] == 'light3') {this.light3 = sprite;}
                if (sprite['uid'] == 'light4') {this.light4 = sprite;}
                if (sprite['uid'] == 'light5') {this.light5 = sprite;}
                if (sprite['uid'] == 'light6') {this.light6 = sprite;}
            }
            else if (sprite.sprite == 'miror') {
                sprite.animations.add('normal', [0]);
                sprite.animations.add('breaking', [0,1,2]);
                sprite.animations.play('normal', 0, false);
            }
            else if (sprite.sprite == 'window') {
                sprite.animations.add('normal', [0]);
                sprite.animations.add('moving', [0,1,2,3,0]);
                sprite.animations.play('normal', 0, false);
                sprite.alpha = 0;
            }
            else if (sprite.sprite == 'imgBallon') {
                sprite.alpha = 0;
            }
            else if (sprite.sprite == 'tambourin') {
                this.tambourinSprite = sprite;
                this.tambourinSprite.animations.add('normal', [0]);
                this.tambourinSprite.animations.add('playing', [0,1,2,3,4,1,2,3,4,0]);
                this.tambourinSprite.animations.play('normal', 0, false);
            }
            
        }, this);
        
    },
    
};